summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/catmanlistitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/catmanlistitem.h')
-rw-r--r--kbabel/catalogmanager/catmanlistitem.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kbabel/catalogmanager/catmanlistitem.h b/kbabel/catalogmanager/catmanlistitem.h
index e31a5d4d..ac22e2e8 100644
--- a/kbabel/catalogmanager/catmanlistitem.h
+++ b/kbabel/catalogmanager/catmanlistitem.h
@@ -60,11 +60,11 @@ public:
/** the type of this item */
enum Type{File,Dir};
- CatManListItem(CatalogManagerView *view, TQListViewItem* tqparent,TQString fullPath
+ CatManListItem(CatalogManagerView *view, TQListViewItem* parent,TQString fullPath
,TQString fullPotPath,TQString package);
/** creates the toplevel root item with package name "/" */
- CatManListItem(CatalogManagerView *view, TQListView* tqparent,TQString fullPath, TQString fullPotPath);
+ CatManListItem(CatalogManagerView *view, TQListView* parent,TQString fullPath, TQString fullPotPath);
/**
* returns the package names (including relative path) of the
@@ -94,7 +94,7 @@ public:
/**
* checks if the file on the disc has changed,
* reads information about the file and displays it
* @param noParents flag, if the update has to include the tqparent
* of the item, if the status has changed. Since at the first build of
* the tree, the status of every item changes, this is not useful then.
*/
@@ -227,7 +227,7 @@ private:
/** a list of errors found by validation tool*/
TQValueList<IgnoreItem> _errors;
/** tqparent view for this item, used for stopping the activity */
CatalogManagerView *_view;
/** index of words, but it does not contain any useful information as values */
@@ -94,7 +94,7 @@ public:
* checks if the file on the disc has changed,
* reads information about the file and displays it
- * @param noParents flag, if the update has to include the tqparent
+ * @param noParents flag, if the update has to include the parent
* of the item, if the status has changed. Since at the first build of
* the tree, the status of every item changes, this is not useful then.
@@ -227,7 +227,7 @@ private:
/** a list of errors found by validation tool*/
TQValueList<IgnoreItem> _errors;
- /** tqparent view for this item, used for stopping the activity */
+ /** parent view for this item, used for stopping the activity */
CatalogManagerView *_view;
/** index of words, but it does not contain any useful information as values */